cc430radioconfig - CC430 Radio Configuration Module
======================================

The commandmodule Faraday Python module is a collection of functions that perform calculations and other actions for the CC430 radio module settings.

.. automodule:: cc430radioconfig
    :members:
